import { Component, OnInit, ViewChild } from '@angular/core';
import { IGridKeydownEventArgs, IgxColumnComponent, IgxGridComponent } from 'igniteui-angular';
import { IgxGridCellComponent } from 'igniteui-angular/lib/grids/cell.component';

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.scss']
})
export class AppComponent implements OnInit {
  title = 'igx-grid-template-editor';
  localData: any = [];
  @ViewChild('grid1') grid1!: IgxGridComponent;

  ngOnInit() {
    for (let i = 1; i <= 50; i++) {
      this.localData.push(
        {
          id: i,
          productId: 372720 + i,
          productName: `HK Shirt ${i}`,
          color: 'Blue',
          position: 'top',
          deisgn: 'A',
          unitPrice: 100
        }
      );
    }
  }

  customKeydown(args: any) {
    const target = args.target as IgxGridCellComponent;
    const type = args.targetType;
    const keyboardEvt = args.event as KeyboardEvent;

    if (type === "dataCell" && keyboardEvt.key.toLowerCase() === "tab") {
      // When tab is hit
      args.event.preventDefault();
      args.cancel = true;

      const cell = keyboardEvt.shiftKey ?
        this.grid1.getPreviousCell(target.rowIndex, target.visibleColumnIndex, (col) => col.editable) :
        this.grid1.getNextCell(target.rowIndex, target.visibleColumnIndex, (col: IgxColumnComponent) => {
          return col.header === 'Product Name' ||
          col.header === 'Position' ||
          col.header === 'Design';
        });

      this.grid1.navigateTo(cell.rowIndex, cell.visibleColumnIndex,
        (obj) => {
          // Focus on editable UI element
          obj.target.nativeElement.children[0].focus();
        });
    }
    if (type === "dataCell" && keyboardEvt.code.toLowerCase() === "space") {
      // When space is hit
      args.cancel = true;
      console.log('space');
    }
  }

  updateCell(cell: IgxGridCellComponent, args: Event) {
    const input = args.target as HTMLInputElement;
    cell.update(input.value);
  }
}
